# `ase-hdf5`

<div align="center">

![PyPI - Version](https://img.shields.io/pypi/v/ase-hdf5)
[![GitHub License](https://img.shields.io/github/license/tcnicholas/ase-hdf5)](LICENSE.md)
[![](https://github.com/tcnicholas/ase-hdf5/actions/workflows/tests.yaml/badge.svg?branch=main)](https://github.com/tcnicholas/ase-hdf5/actions/workflows/tests.yaml)
[![codecov](https://codecov.io/gh/tcnicholas/ase-hdf5/graph/badge.svg?token=LX45880JL6)](https://codecov.io/gh/tcnicholas/ase-hdf5)
</div>

`ase-hdf5` provides a simple I/O for list[ase.Atoms] <—> HDF5.